<?xml version="1.0" encoding="utf-8"?>

<!-- Original Chinese translation done by LinuxToy (https://twitter.com/linuxtoy) -->

<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>ColorParameter</name>
    <message>
        <location filename="../src/FilterParameters/ColorParameter.cpp" line="133"/>
        <source>Select color</source>
        <translation>选择颜色</translation>
    </message>
</context>
<context>
    <name>DialogSettings</name>
    <message>
        <location filename="../ui/dialogsettings.ui" line="14"/>
        <source>Dialog</source>
        <translation>对话框</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="221"/>
        <source>Internet updates</source>
        <translation>因特网更新</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="230"/>
        <source>Update now</source>
        <translation>立即更新</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="30"/>
        <source>Layout</source>
        <translation>布局</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="24"/>
        <source>Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="64"/>
        <source>Preview on the &amp;left</source>
        <translation>在左边预览(&amp;L)</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="94"/>
        <source>Pre&amp;view on right side</source>
        <translation>在右边预览(&amp;V)</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="113"/>
        <source>Theme</source>
        <translation>主题</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="119"/>
        <source>&amp;Default</source>
        <translation>默认(&amp;D)</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="126"/>
        <source>Dar&amp;k</source>
        <translation>暗色(&amp;K)</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="139"/>
        <source>&lt;i&gt;(Restart needed)&lt;/I&gt;</source>
        <translation>&lt;i&gt;(必须重启)&lt;/I&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="149"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="179"/>
        <source>Always enable preview zooming</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="186"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-style:italic;&quot;&gt;(Warning: preview may be inaccurate&lt;br/&gt;if checked.)&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="215"/>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="253"/>
        <location filename="../src/DialogSettings.cpp" line="84"/>
        <source>Output messages</source>
        <translation>输出信息</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="196"/>
        <source>Dialogs</source>
        <translation>对话框</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="202"/>
        <source>Use native color dialog</source>
        <translation>使用原生颜色对话框</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="163"/>
        <source>Preview</source>
        <translation>预览</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="169"/>
        <source>Timeout (seconds)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="36"/>
        <source>Show institution logos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="262"/>
        <source>Notify when scheduled update fails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="304"/>
        <source>&amp;Ok</source>
        <translation>确定(&amp;O)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="64"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="70"/>
        <source>Never</source>
        <translation>从不</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="71"/>
        <source>Daily</source>
        <translation>每日</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="72"/>
        <source>Weekly</source>
        <translation>每周</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="73"/>
        <source>Every 2 weeks</source>
        <translation>每隔两周</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="74"/>
        <source>Monthly</source>
        <translation>每月</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="76"/>
        <source>At launch (debug)</source>
        <translation>启动时 (调试)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="85"/>
        <source>Output messages...</source>
        <translation>输出信息...</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="86"/>
        <source>Quiet (default)</source>
        <translation>静默 (默认)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="87"/>
        <source>Verbose (layer name)</source>
        <translation>冗长 (层名)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="88"/>
        <source>Verbose (console)</source>
        <translation>冗长 (控制台)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="89"/>
        <source>Verbose (log file)</source>
        <translation>冗长 (日志文件)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="90"/>
        <source>Very verbose (console)</source>
        <translation>很冗长 (控制台)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="91"/>
        <source>Very verbose (log file)</source>
        <translation>很冗长 (日志文件)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="92"/>
        <source>Debug (console)</source>
        <translation>调试 (控制台)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="93"/>
        <source>Debug (log file)</source>
        <translation>调试 (日志文件)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="109"/>
        <source>Check to use Native/OS color dialog, uncheck to use Qt&apos;s</source>
        <translation>选择以便使用原生/系统颜色对话框，取消选择以便使用 Qt</translation>
    </message>
</context>
<context>
    <name>FileParameter</name>
    <message>
        <location filename="../src/FilterParameters/FileParameter.cpp" line="148"/>
        <location filename="../src/FilterParameters/FileParameter.cpp" line="151"/>
        <location filename="../src/FilterParameters/FileParameter.cpp" line="154"/>
        <source>Select a file</source>
        <translation>选择一个文件</translation>
    </message>
</context>
<context>
    <name>FilterParametersWidget</name>
    <message>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="39"/>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="172"/>
        <source>&lt;i&gt;Select a filter&lt;/i&gt;</source>
        <translation>&lt;i&gt;选择一个滤镜&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="139"/>
        <source>&lt;i&gt;No parameters&lt;/i&gt;</source>
        <translation>&lt;i&gt;无参数&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="144"/>
        <source>Error parsing filter parameters

</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FiltersPresenter</name>
    <message>
        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="411"/>
        <source>Cannot find this fave&apos;s original filter
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FiltersView</name>
    <message>
        <location filename="../ui/filtersview.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="64"/>
        <source>Rename fave</source>
        <translation>重命名收藏</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="66"/>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="338"/>
        <source>Remove fave</source>
        <translation>移除收藏</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="68"/>
        <source>Clone fave</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="72"/>
        <source>Add fave</source>
        <translation>添加收藏</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="338"/>
        <source>Do you really want to remove the following fave?

%1
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FolderParameter</name>
    <message>
        <location filename="../src/FilterParameters/FolderParameter.cpp" line="126"/>
        <source>Select a folder</source>
        <translation>选择一个文件夹</translation>
    </message>
</context>
<context>
    <name>HeadlessProgressDialog</name>
    <message>
        <location filename="../ui/headlessprogressdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>对话框</translation>
    </message>
    <message>
        <location filename="../ui/headlessprogressdialog.ui" line="68"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>InOutPanel</name>
    <message>
        <location filename="../ui/inoutpanel.ui" line="40"/>
        <source>Input / Output</source>
        <translation>输入 / 输出</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="47"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="102"/>
        <location filename="../src/Widgets/InOutPanel.cpp" line="45"/>
        <source>Input layers</source>
        <translation>输入层</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="46"/>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="47"/>
        <source>Active (default)</source>
        <translation>活动 (默认)</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="48"/>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="49"/>
        <source>Active and below</source>
        <translation>活动及其下面</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="50"/>
        <source>Active and above</source>
        <translation>活动及其上面</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="51"/>
        <source>All visible</source>
        <translation>全部可见</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="52"/>
        <source>All invisible</source>
        <translation>全部不可见</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="53"/>
        <source>All visible (decr.)</source>
        <translation>全部可见 (decr.)</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="54"/>
        <source>All invisible (decr.)</source>
        <translation>全部不可见 (decr.)</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="55"/>
        <source>All (decr.)</source>
        <translation>全部 (decr.)</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="138"/>
        <location filename="../src/Widgets/InOutPanel.cpp" line="57"/>
        <source>Output mode</source>
        <translation>输出模式</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="58"/>
        <source>In place (default)</source>
        <translation>就地 (默认)</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="59"/>
        <source>New layer(s)</source>
        <translation>新建层</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="60"/>
        <source>New active layer(s)</source>
        <translation>新建活动层</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="61"/>
        <source>New image</source>
        <translation>新建图像</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="125"/>
        <location filename="../src/Widgets/InOutPanel.cpp" line="63"/>
        <source>Preview mode</source>
        <translation>预览模式</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="64"/>
        <source>1st output (default)</source>
        <translation>第一个输出 (默认)</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="65"/>
        <source>2nd output</source>
        <translation>第二个输出</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="66"/>
        <source>3rd output</source>
        <translation>第三个输出</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="67"/>
        <source>4th output</source>
        <translation>第四个输出</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="68"/>
        <source>1st -&gt; 2nd output</source>
        <translation>第一 -&gt; 第二个输出</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="69"/>
        <source>1st -&gt; 3rd output</source>
        <translation>第一 -&gt; 第三个输出</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="70"/>
        <source>1st -&gt; 4th output</source>
        <translation>第一 -&gt; 第四个输出</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="71"/>
        <source>All outputs</source>
        <translation>全部输出</translation>
    </message>
</context>
<context>
    <name>LanguageSelectionWidget</name>
    <message>
        <location filename="../ui/languageselectionwidget.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/languageselectionwidget.ui" line="38"/>
        <source>&lt;i&gt;(Restart needed)&lt;/i&gt;</source>
        <translation>&lt;i&gt;(必须重启)&lt;/I&gt;</translation>
    </message>
    <message>
        <location filename="../src/Widgets/LanguageSelectionWidget.cpp" line="45"/>
        <source>System default (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ui/mainwindow.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="161"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Download filter definitions from remote sources&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;从远端来源下载滤镜定义&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="164"/>
        <source>Internet</source>
        <translation>因特网</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="104"/>
        <source>Selection mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="489"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="233"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="379"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enable/disable preview&lt;br/&gt;(Ctrl+P)&lt;br/&gt;(right click on preview image for instant swapping)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="382"/>
        <source>Preview</source>
        <translation>预览</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="473"/>
        <source>Settings...</source>
        <translation>设置...</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="502"/>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="515"/>
        <source>&amp;Fullscreen</source>
        <translation>全屏(&amp;F)</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="528"/>
        <source>&amp;Apply</source>
        <translation>应用(&amp;A)</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="541"/>
        <source>&amp;OK</source>
        <translation>确定(&amp;O)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="82"/>
        <source>Add fave</source>
        <translation>添加收藏</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="84"/>
        <source>Reset parameters to default values</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="87"/>
        <source>Update filters (Ctrl+R / F5)</source>
        <translation>更新滤镜</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="89"/>
        <source>Rename fave</source>
        <translation>重命名收藏</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="91"/>
        <source>Remove fave</source>
        <translation>移除收藏</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="95"/>
        <source>Expand/Collapse all</source>
        <translation>全部展开/折叠</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="97"/>
        <source>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;Normandy University (https://www.unicaen.fr)&lt;br/&gt;Ensicaen (https://www.ensicaen.fr)</source>
        <translation>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;诺曼底大学 (https://www.unicaen.fr)&lt;br/&gt;法国国立卡昂高等工程师学院 (https://www.ensicaen.fr)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="287"/>
        <source>Update completed</source>
        <translation>更新完成</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="287"/>
        <location filename="../src/MainWindow.cpp" line="289"/>
        <location filename="../src/MainWindow.cpp" line="343"/>
        <source>Filter definitions have been updated.</source>
        <translation>滤镜定义已更新。</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="292"/>
        <source>No download was needed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="339"/>
        <source>Filters update could not be achieved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="461"/>
        <source>The update could not be achieved&lt;br&gt;because of the following errors:&lt;br&gt;</source>
        <translation>这次更新由于以下错误&lt;br/&gt;不能完成:&lt;br/&gt;</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="467"/>
        <source>Update error</source>
        <translation>更新错误</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="650"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="742"/>
        <source>Waiting for cancelled jobs...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1078"/>
        <source>Import faves</source>
        <translation>导入收藏</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1078"/>
        <source>Do you want to import faves from file below?&lt;br/&gt;%1</source>
        <translation>你要从下面文件导入收藏吗?&lt;br/&gt;%1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1081"/>
        <source>Don&apos;t ask again</source>
        <translation>别再问</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1193"/>
        <source>Confirmation</source>
        <translation>确认</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1193"/>
        <source>A gmic command is running.&lt;br&gt;Do you really want to close the plugin?</source>
        <translation>gmic 命令正在运行。&lt;br&gt;你真的想要关闭插件吗?</translation>
    </message>
</context>
<context>
    <name>MultilineTextParameterWidget</name>
    <message>
        <location filename="../ui/multilinetextparameterwidget.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/multilinetextparameterwidget.ui" line="29"/>
        <source>Update</source>
        <translation>更新</translation>
    </message>
    <message>
        <location filename="../src/FilterParameters/MultilineTextParameterWidget.cpp" line="38"/>
        <source>Ctrl+Return</source>
        <translation>Ctrl+Return</translation>
    </message>
</context>
<context>
    <name>ProgressInfoWidget</name>
    <message>
        <location filename="../ui/progressinfowidget.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowidget.ui" line="48"/>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="48"/>
        <source>Abort</source>
        <translation>中止</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowidget.ui" line="55"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="45"/>
        <source>G&apos;MIC-Qt Plug-in progression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="143"/>
        <source>Updating filters...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="198"/>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="211"/>
        <source>[Processing %1 | %2]</source>
        <translation>[进度 %1 | %2]</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="213"/>
        <source>[Processing %1]</source>
        <translation>[进度 %1]</translation>
    </message>
</context>
<context>
    <name>ProgressInfoWindow</name>
    <message>
        <location filename="../ui/progressinfowindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowindow.ui" line="30"/>
        <location filename="../ui/progressinfowindow.ui" line="50"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowindow.ui" line="72"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="134"/>
        <source>%1 seconds</source>
        <translation>%1 秒</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="144"/>
        <source>[Processing %1 | %2]</source>
        <translation>[进度 %1 | %2]</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="146"/>
        <source>[Processing %1]</source>
        <translation>[进度 %1]</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="82"/>
        <source>Select an image to open...</source>
        <translation>选择一幅图片打开...</translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="82"/>
        <source>PNG &amp; JPG files (*.png *.jpeg *.jpg *.PNG *.JPEG *.JPG)</source>
        <translation>PNG &amp; JPG 文件 (*.png *.jpeg *.jpg *.PNG *.JPEG *.JPG)</translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="88"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="88"/>
        <source>Could not open file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="92"/>
        <source>Default image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="87"/>
        <source>Visible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="85"/>
        <source>Available filters (%1)</source>
        <translation>可用滤镜 (%1)</translation>
    </message>
</context>
<context>
    <name>SearchFieldWidget</name>
    <message>
        <location filename="../ui/SearchFieldWidget.ui" line="20"/>
        <source>Frame</source>
        <translation>Frame</translation>
    </message>
    <message>
        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="76"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="77"/>
        <source>Search in filters list (%1)</source>
        <translation>在滤镜列表中搜索 (%1)</translation>
    </message>
</context>
<context>
    <name>Updater</name>
    <message>
        <location filename="../src/Updater.cpp" line="208"/>
        <source>Could not read/decompress %1</source>
        <translation>无法读取/解压缩 %1</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="199"/>
        <source>Error downloading %1 (empty file?)</source>
        <translation>下载错误 %1 (空文件?)</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="214"/>
        <source>Error creating file %1</source>
        <translation>创建文件错误 %1</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="218"/>
        <source>Error writing file %1</source>
        <translation>写入文件错误 %1</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="235"/>
        <source>Error downloading %1&lt;br/&gt;Error %2: %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="268"/>
        <source>Download timeout: %1</source>
        <translation>下载超时: %1</translation>
    </message>
</context>
<context>
    <name>ZoomLevelSelector</name>
    <message>
        <location filename="../ui/zoomlevelselector.ui" line="20"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="51"/>
        <source>Zoom in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="52"/>
        <source>Zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="53"/>
        <source>Reset zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="153"/>
        <source>Warning: Preview may be inaccurate (zoom factor has been modified)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
